drop table NCBOCATEGORIES CASCADE CONSTRAINTS;
drop table NCBOFILE CASCADE CONSTRAINTS;
drop table NCBOFILECATEGORY CASCADE CONSTRAINTS;
drop table NCBOFILEMETADATAINFO CASCADE CONSTRAINTS;
drop table NCBOFILENAMES CASCADE CONSTRAINTS;
drop table NCBOFILEVERSIONINFO CASCADE CONSTRAINTS;
drop table NCBOUSERROLE CASCADE CONSTRAINTS;
drop table NCBOUSER CASCADE CONSTRAINTS;
drop table NCBOROLE CASCADE CONSTRAINTS;
drop table NCBOJOBTYPE CASCADE CONSTRAINTS;
drop TABLE NCBOJOBSTATE CASCADE CONSTRAINTS;
DROP TABLE NCBOALLOWEDSTATECHANGE CASCADE CONSTRAINTS;
DROP TABLE NCBOJOBSTATECHANGE CASCADE CONSTRAINTS;
DROP TABLE NCBOJOB CASCADE CONSTRAINTS;
DROP TABLE NCBOTRACESEARCH CASCADE CONSTRAINTS;
DROP TABLE NCBOSEARCHTRACESINGLE CASCADE CONSTRAINTS;

drop sequence NCBOSEQ_STORE;


CREATE TABLE NCBOUSER 
   (	"ID" NUMBER, 
	"LOGIN" VARCHAR2(50), 
	"PASSWORD" VARCHAR2(50), 
	"EMAIL" VARCHAR2(100), 
	"FIRSTNAME" VARCHAR2(50), 
	"LASTNAME" VARCHAR2(50), 
	"PHONE" VARCHAR2(30), 
	"VALIDATETOKEN" VARCHAR2(20), 
	"ISVALIDATED" CHAR(1) DEFAULT 'N', 
	 PRIMARY KEY ("ID")
    ) ;
 
  CREATE TABLE NCBOROLE 
   (	"ID" NUMBER, 
	"NAME" VARCHAR2(100), 
	"DESCRIPTION" VARCHAR2(255), 
	 PRIMARY KEY ("ID")
 
   ) ;
 
 
  CREATE UNIQUE INDEX NCBOROLE_INDEX ON NCBOROLE ("NAME") ;
  
 
  CREATE TABLE NCBOCATEGORIES 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"NAME" VARCHAR2(100) NOT NULL ENABLE, 
	"PARENTCATEGORYID" NUMBER, 
	 CONSTRAINT "NCBOCATEGORIES_PK" PRIMARY KEY ("ID"),
	 CONSTRAINT "NCBOCATEGORIES_NCBOCATEGO_FK1" FOREIGN KEY ("PARENTCATEGORYID")
	  REFERENCES NCBOCATEGORIES ("ID") ENABLE
   ) ;
 
  

CREATE TABLE NCBOFILE 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"USERID" NUMBER NOT NULL ENABLE, 
	"CREATIONDATE" TIMESTAMP (6), 
	"FILEPATH" VARCHAR2(4000), 
	"RELEASEDATE" TIMESTAMP (6), 
	"ROOTVERSIONID" NUMBER, 
	"ISREMOTE" NUMBER(*,0), 
	"METADADATAINFOID" NUMBER, 
	"DOWNLOADURL" VARCHAR2(4000), 
	"ISREVIEWED" NUMBER(*,0) DEFAULT 1, 
	 CONSTRAINT "NCBOFILE_PK" PRIMARY KEY ("ID"),
   	 CONSTRAINT "NCBOFILE_NCBOUSER_FK1" FOREIGN KEY ("USERID")
	  REFERENCES NCBOUSER ("ID") ENABLE
   ) ;
 
  
  
   CREATE TABLE "NCBOFILECATEGORY" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"NCBOFILEID" NUMBER NOT NULL ENABLE, 
	"CATEGORYID" NUMBER NOT NULL ENABLE, 
	 CONSTRAINT "NCBOCATEGORY_PK" PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "NCBOCATEGORY_NCBOFILE_FK1" FOREIGN KEY ("NCBOFILEID")
	  REFERENCES "NCBOFILE" ("ID") ENABLE, 
	 CONSTRAINT "NCBOFILECATEGORY_NCBOCATE_FK1" FOREIGN KEY ("CATEGORYID")
	  REFERENCES "NCBOCATEGORIES" ("ID") ENABLE
   ) ;
 
 
 CREATE TABLE NCBOFILEMETADATAINFO 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"DISPLAYLABEL" VARCHAR2(100), 
	"METADATAPATH" VARCHAR2(4000), 
	"CODINGSCHEMENAME" VARCHAR2(40), 
	"FORMAT" VARCHAR2(50), 
	"CURRENTVERSION" VARCHAR2(40), 
	"CURRENTVERSIONSTATUS" VARCHAR2(4000), 
	"CONTACTNAME" VARCHAR2(100), 
	"CONTACTEMAIL" VARCHAR2(100), 
	"HOMEPAGE" VARCHAR2(200), 
	"DOCUMENTATION" VARCHAR2(200), 
	"PUBLICATION" VARCHAR2(200), 
	"ISFOUNDRY" CHAR(1) DEFAULT 'N', 
	"URN" VARCHAR2(500),
	"NUMBEROFCLASSES" NUMBER,
	"PARSEDMETADATA" char(1) DEFAULT 'N',
	 CONSTRAINT "NCBOFILEMETADATAINFO_PK" PRIMARY KEY ("ID") ENABLE
   ) ;
 
  

  CREATE UNIQUE INDEX NCBO_DISPLAYLABEL_INDEX ON NCBOFILEMETADATAINFO ("DISPLAYLABEL") ;
 
CREATE TABLE NCBOFILENAMES 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"NCBOFILE" NUMBER NOT NULL ENABLE, 
	"FILENAME" VARCHAR2(100) NOT NULL ENABLE, 
	 CONSTRAINT "NCBOFILENAMES_PK" PRIMARY KEY ("ID")   ENABLE, 
	 CONSTRAINT "NCBOFILENAMES_NCBOFILE_FK1" FOREIGN KEY ("NCBOFILE")
	  REFERENCES NCBOFILE ("ID") ENABLE
   ) ;
 
  
 
 
  CREATE INDEX NCBOFILENAMES_INDEX1 ON NCBOFILENAMES ("NCBOFILE") ;
 
 
  CREATE TABLE NCBOFILEVERSIONINFO
   (	"ID" NUMBER NOT NULL ENABLE, 
	"PARENTVERSIONID" NUMBER, 
	"VERSIONNUMBER" NUMBER NOT NULL ENABLE, 
	"ISCURRENT" NUMBER(*,0) DEFAULT 1, 
	 CONSTRAINT "NCBOFILEVERSION_PK" PRIMARY KEY ("ID")  ENABLE
   ) ;
 
 
  CREATE INDEX NCBOFILEVERSIONINFO_INDEX1 ON NCBOFILEVERSIONINFO ("ISCURRENT") ;

 
 CREATE TABLE NCBOUSERROLE 
   (	"ID" NUMBER, 
	"USERID" NUMBER NOT NULL ENABLE, 
	"ROLEID" NUMBER NOT NULL ENABLE, 
	 PRIMARY KEY ("ID")  ENABLE
   ) ;
 
  CREATE TABLE "NCBOONTOLOGYACCESS" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"METADATAINFOID" NUMBER NOT NULL ENABLE, 
	"USERID" NUMBER NOT NULL ENABLE, 
	 CONSTRAINT "NCBOONTOLOGYACCESS_PK" PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "NCBOONTOLOGYACCESS_NCBOFI_FK1" FOREIGN KEY ("METADATAINFOID")
	  REFERENCES "CBIO"."NCBOFILEMETADATAINFO" ("ID") ENABLE, 
	 CONSTRAINT "NCBOONTOLOGYACCESS_NCBOUS_FK1" FOREIGN KEY ("USERID")
	  REFERENCES "NCBOUSER" ("ID") ENABLE
   ) ;
 


	  
 
  CREATE INDEX NCBOUSERROLE_INDEX ON NCBOUSERROLE ("USERID") ;
 
 
   CREATE SEQUENCE NCBOSEQ_STORE  MINVALUE 1 MAXVALUE 999999999999999999999999999 INCREMENT BY 1 START WITH 2801 CACHE 20 NOORDER  NOCYCLE;

-- INSERTING into NCBOCATEGORIES
Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Other',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Chemical',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Development',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Ethology',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Experimental Conditions',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Genomic and Proteomic',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Phenotype',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Taxonomic Classification',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Vocabularies',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Anatomy',null);

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Gross Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Anatomy') where name='Gross Anatomy';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Animal Gross Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Gross Anatomy') where name='Animal Gross Anatomy';


Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Fish Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Animal Gross Anatomy') where name= 'Fish Anatomy';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Human Developmental Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Animal Gross Anatomy') where name= 'Human Developmental Anatomy';


Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Microbial Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Gross Anatomy') where name = 'Microbial Anatomy';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Plant Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Gross Anatomy') where name = 'Plant Anatomy';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Mouse Anatomy',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Animal Gross Anatomy') where name= 'Mouse Anatomy';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Animal Development',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Development') where name= 'Animal Development';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Plant Development',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Development') where name= 'Plant Development';

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Gene Product',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Genomic and Proteomic') where name='Gene Product' ;

Insert into NCBOCATEGORIES values (NCBOSEQ_STORE.nextval,'Protein',null);
update NCBOCATEGORIES set parentcategoryid = (select id from NCBOCATEGORIES where name='Gene Product') where name='Protein';



-- INSERTING into NCBOROLE
Insert into NCBOROLE values (NCBOSEQ_STORE.nextval,'OBO Developer','Can develop ontologies');
Insert into NCBOROLE values (NCBOSEQ_STORE.nextval,'OBO Librarian','Can validate Ontologies');
Insert into NCBOROLE values (NCBOSEQ_STORE.nextval,'OBO Administrator','Has administration priveleges');

CREATE TABLE "NCBOJOBTYPE" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"DESCRIPTION" VARCHAR2(200) NOT NULL ENABLE, 
	"DISPLAYNAME" VARCHAR2(50) NOT NULL ENABLE, 
	"STARTHANDLER" VARCHAR2(200) NOT NULL ENABLE, 
	 PRIMARY KEY ("ID")  ENABLE
   ) ;

CREATE TABLE "NCBOJOBSTATE" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"DESCRIPTION" VARCHAR2(200) NOT NULL ENABLE, 
	"DISPLAYNAME" VARCHAR2(50) NOT NULL ENABLE, 
	"JOBTYPEID" NUMBER(*,0), 
	"ALLOWEDACTION" VARCHAR2(20),
	 PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "FKAEF601B6D811B357" FOREIGN KEY ("JOBTYPEID")
	  REFERENCES "NCBOJOBTYPE" ("ID") ENABLE
   ) ;
 
  CREATE TABLE "NCBOALLOWEDSTATECHANGE" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"HANDLER" VARCHAR2(200), 
	"BEGINSTATEID" NUMBER(*,0), 
	"ENDSTATEID" NUMBER(*,0), 
	"JOBTYPEID" NUMBER(*,0), 
	 PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "FK3019293BD811B357" FOREIGN KEY ("JOBTYPEID")
	  REFERENCES "NCBOJOBTYPE" ("ID") ENABLE, 
	 CONSTRAINT "FK3019293B9EF2862C" FOREIGN KEY ("BEGINSTATEID")
	  REFERENCES "NCBOJOBSTATE" ("ID") ENABLE, 
	 CONSTRAINT "FK3019293BDCAE39BA" FOREIGN KEY ("ENDSTATEID")
	  REFERENCES "NCBOJOBSTATE" ("ID") ENABLE
   ) ;
 
  CREATE TABLE "NCBOJOBSTATECHANGE" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"LASTMESSAGE" VARCHAR2(4000), 
	"STATECHANGEDATE" TIMESTAMP (6), 
	"STATECHANGEID" NUMBER(*,0), 
	"JOBID" NUMBER(*,0), 
	 PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "FK189B61061639AA36" FOREIGN KEY ("STATECHANGEID")
	  REFERENCES "NCBOALLOWEDSTATECHANGE" ("ID") ENABLE, 
	 CONSTRAINT "FK189B6106243D5B43" FOREIGN KEY ("JOBID")
	  REFERENCES "NCBOJOB" ("ID") ENABLE
   ) ;
 

 
  
  
 

--NCBOJob
CREATE TABLE NCBOJOB 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"LASTMESSAGE" VARCHAR2(4000), 
	"STATEBEGINDATE" TIMESTAMP (6), 
	"CURRENTSTATEID" NUMBER(*,0), 
	"JOBTYPEID" NUMBER(*,0), 
	"TARGETID" NUMBER NOT NULL ENABLE, 
	 PRIMARY KEY ("ID") ENABLE, 
	 CONSTRAINT "FK9441DB9BF594C379" FOREIGN KEY ("CURRENTSTATEID")
	  REFERENCES "NCBOJOBSTATE" ("ID") ENABLE, 
	 CONSTRAINT "FK9441DB9BD811B357" FOREIGN KEY ("JOBTYPEID")
	  REFERENCES "NCBOJOBTYPE" ("ID") ENABLE
   ) ;

 CREATE TABLE "NCBOTRACESEARCH" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"ONTOLOGYLABELS" VARCHAR2(4000), 
	"SEARCHTYPE" VARCHAR2(10) NOT NULL ENABLE, 
	"PROPERTY" NUMBER(1,0), 
	"CLASSANDID" NUMBER(1,0), 
	"DEFINITION" NUMBER(1,0), 
	"METADATA" NUMBER(1,0), 
	"COUNT" NUMBER(*,0) NOT NULL ENABLE, 
	"SEARCHTEXT" VARCHAR2(4000) NOT NULL ENABLE, 
	"SEARCHALGORITHM" VARCHAR2(100), 
	 CONSTRAINT "NCBOTRACESEARCH_PK" PRIMARY KEY ("ID") ENABLE
   ) ;
 
 

CREATE TABLE "NCBOSEARCHTRACESINGLE" 
   (	"ID" NUMBER NOT NULL ENABLE, 
	"SEARCHTRACEID" NUMBER, 
	"TAB" VARCHAR2(100), 
	"COUNT" NUMBER(*,0), 
	 CONSTRAINT "NCBOSEARCHTRACESINGLE_PK" PRIMARY KEY ("ID") ENABLE
   ) ;
 
  
 
 -- INSERTING into NCBOJOBTYPE
Insert into NCBOJOBTYPE values (ncboseq_store.nextVal,'File  submit','SUBMIT_FILE','org.ncbo.stanford.server.mdb.ValidateStateProducer');


Insert into NCBOJOBTYPE values (ncboseq_store.nextVal,'File  submit PRE LIBRARIAN REVIEW','SUBMIT_FILE_VALIDATE','org.ncbo.stanford.server.mdb.ValidateStateProducer');

Insert into NCBOJOBTYPE values (ncboseq_store.nextVal,'Parse metadata file on update or submit','PARSE_METADATA','org.ncbo.stanford.server.mdb.LoadMetadataStateProducer');
--
Insert into NCBOJOBTYPE values (ncboseq_store.nextVal,'Convert file to OWL for URI','CONVERT_FILE_URI','org.ncbo.stanford.server.mdb.ConvertStateProducer');
--


-- INSERTING into NCBOJOBSTATE

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Validate File In progress','VALIDATE_FILE',null,'NONE');
update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='VALIDATE_FILE';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Validate File Error','VALIDATE_FILE_ERROR',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='VALIDATE_FILE_ERROR';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Validate file Success','VALIDATE_FILE_END',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='VALIDATE_FILE_END';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load content In progress','PARSE_FILE',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load content Error','PARSE_FILE_ERROR',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE_ERROR';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load content Success','PARSE_FILE_END',null,'SEARCH,VISUALIZE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE_END';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load metadata In progress','PARSE_FILE_METADATA',null,'SEARCH,VISUALIZE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE_METADATA';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load metadata Error','PARSE_FILE_METADATA_ERROR',null,'SEARCH,VISUALIZE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE_METADATA_ERROR';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Load metadata Success','PARSE_FILE_METADATA_END',null,'SEARCH_METADATA');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='SUBMIT_FILE') where  displayname='PARSE_FILE_METADATA_END';

---
Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Convert File In progress','CONVERT_FILE_URI',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='CONVERT_FILE_URI') where  displayname='CONVERT_FILE_URI';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Convert file Error','CONVERT_FILE_URI_ERROR',null,'NONE');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='CONVERT_FILE_URI') where  displayname='CONVERT_FILE_URI_ERROR';

Insert into NCBOJOBSTATE values (ncboseq_store.nextVal,'Convert file Success','CONVERT_FILE_URI_END',null,'URI');

update NCBOJOBSTATE set jobTypeId = (select id from NCBOJOBTYPE where displayname='CONVERT_FILE_URI') where  displayname='CONVERT_FILE_URI_END';

---


--INSERTING INTO NCBOALLOWEDSTATECHANGE
INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='VALIDATE_FILE' AND C.DISPLAYNAME='VALIDATE_FILE_ERROR' AND D.DISPLAYNAME='SUBMIT_FILE';


INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='VALIDATE_FILE' AND C.DISPLAYNAME='VALIDATE_FILE_END' AND D.DISPLAYNAME='SUBMIT_FILE';


INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,'org.ncbo.stanford.server.mdb.LoadStateProducer',B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='VALIDATE_FILE_END' AND C.DISPLAYNAME='PARSE_FILE' AND D.DISPLAYNAME='SUBMIT_FILE';


INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE' AND C.DISPLAYNAME='PARSE_FILE_ERROR' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE' AND C.DISPLAYNAME='PARSE_FILE_END' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,'org.ncbo.stanford.server.mdb.LoadMetadataStateProducer',B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_END' AND C.DISPLAYNAME='PARSE_FILE_METADATA' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_METADATA' AND C.DISPLAYNAME='PARSE_FILE_METADATA_END' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_METADATA' AND C.DISPLAYNAME='PARSE_FILE_METADATA_ERROR' AND D.DISPLAYNAME='SUBMIT_FILE';
--
INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,'org.ncbo.stanford.server.mdb.ConvertStateProducer',B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_METADATA_END' AND C.DISPLAYNAME='CONVERT_FILE_URI' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='CONVERT_FILE_URI' AND C.DISPLAYNAME='CONVERT_FILE_URI_END' AND D.DISPLAYNAME='SUBMIT_FILE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='CONVERT_FILE_URI' AND C.DISPLAYNAME='CONVERT_FILE_URI_ERROR' AND D.DISPLAYNAME='SUBMIT_FILE';
--
 
INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='VALIDATE_FILE' AND C.DISPLAYNAME='VALIDATE_FILE_ERROR' AND D.DISPLAYNAME='SUBMIT_FILE_VALIDATE';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='VALIDATE_FILE' AND C.DISPLAYNAME='VALIDATE_FILE_END' AND D.DISPLAYNAME='SUBMIT_FILE_VALIDATE';
---start
INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='CONVERT_FILE_URI' AND C.DISPLAYNAME='CONVERT_FILE_URI_ERROR' AND D.DISPLAYNAME='CONVERT_FILE_URI';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='CONVERT_FILE_URI' AND C.DISPLAYNAME='CONVERT_FILE_URI_END' AND D.DISPLAYNAME='CONVERT_FILE_URI';
---end
INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_METADATA' AND C.DISPLAYNAME='PARSE_FILE_METADATA_END' AND D.DISPLAYNAME='PARSE_METADATA';

INSERT INTO NCBOALLOWEDSTATECHANGE (ID,HANDLER,BEGINSTATEID,ENDSTATEID,JOBTYPEID) SELECT NCBOSEQ_STORE.NEXTVAL,NULL,B.ID,C.ID,D.ID FROM NCBOJOBSTATE B,NCBOJOBSTATE C,NCBOJOBTYPE D WHERE B.DISPLAYNAME='PARSE_FILE_METADATA' AND C.DISPLAYNAME='PARSE_FILE_METADATA_ERROR' AND D.DISPLAYNAME='PARSE_METADATA';
commit;